@@ -9,18 +9,15 @@ eff_dof <- function(cov.par, X, cov_func, outer.W, taper) {
   n <- nrow(X)
   p <- length(outer.W)
   nug.var <- cov.par[length(cov.par)]
-  Sigma <- Sigma_y(cov.par, p, cov_func, outer.W, taper)
+  Sigma <- Sigma_y(cov.par, cov_func, outer.W, taper)
 
   iSigma <- solve(Sigma)
 
   XtiS <- crossprod(X, iSigma)
 
-  # trace of hat matrix
-  as.numeric(tr(X %*% solve(XtiS %*% X) %*% XtiS))
-
-  # as.numeric(nug.var * tr(solve(XtiS %*% X) %*% XtiS%*% iSigma %*% X) +
-  #   n + nug.var * tr(iSigma))
-
+  # trace of hat matrix (equation 15 in Mueller et al. 2013, Stat. Sci.)
+  as.numeric(nug.var * tr(solve(XtiS %*% X) %*% XtiS %*% iSigma %*% X) +
+    n - nug.var * tr(iSigma))
 }
 
 tr_Sigma <- function(cov.par, X, cov_func, outer.W, taper) {
@@ -30,6 +27,6 @@ tr_Sigma <- function(cov.par, X, cov_func, outer.W, taper) {
   p <- length(outer.W)
 
 
-  tr(Sigma_y(cov.par, p, cov_func, outer.W, taper)) - nug.var*n
+  tr(Sigma_y(cov.par, cov_func, outer.W, taper)) - nug.var*n
 }
 
